//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Canvas/MaskEditorToolbar.h
//! @brief     Defines class MaskEditorToolbar.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORTOOLBAR_H
#define BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORTOOLBAR_H

#include "GUI/View/Scene/MaskEditorFlags.h"
#include <QButtonGroup>
#include <QToolBar>

class MaskEditorActions;

//! Iconic representation of mask editing tools.

class MaskEditorToolbar : public QToolBar {
    Q_OBJECT
public:
    MaskEditorToolbar(MaskEditorActions* editorActions, QWidget* parent = nullptr);

signals:
    void activityChanged(MaskEditorFlags::Activity);
    void presentationChange(bool);
    void maskValueChanged(MaskEditorFlags::MaskValue);

public slots:
    void onChangeActivityRequest(MaskEditorFlags::Activity value);

private:
    void add_separator();

    MaskEditorFlags::Activity currentActivity() const;
    void setCurrentActivity(MaskEditorFlags::Activity value);

    MaskEditorActions* m_editorActions;
    QButtonGroup* m_activityButtonGroup;
    MaskEditorFlags::Activity m_previousActivity;
};

#endif // BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORTOOLBAR_H
