//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/DataView.cpp
//! @brief     Implements class DataView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/DataView.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/View/Data/DatafilesSelector.h"
#include "GUI/View/Data/DatafilesStack.h"
#include "GUI/View/Tool/mainwindow_constants.h"
#include <QAction>
#include <QSplitter>
#include <QVBoxLayout>

DataView::DataView(QWidget* parent, ProjectDocument* document)
    : QWidget(parent)
{
    auto* mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(0);

    auto* splitter = new QSplitter;
    mainLayout->addWidget(splitter);

    auto* selector = new DatafilesSelector(this, document);
    splitter->addWidget(selector);
    selector->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);

    auto* stackedWidget = new DatafilesStack;
    splitter->addWidget(stackedWidget);
    stackedWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    stackedWidget->setSizeHint({1024, 1024});
    connect(selector, &DatafilesSelector::selectionChanged,
            [=](DatafileItem* realItem) { stackedWidget->setItem(realItem); });

    splitter->setCollapsible(0, false);
    splitter->setCollapsible(1, false);
    splitter->setSizes(QList<int>() << GUI::Style::ITEM_SELECTOR_WIDGET_WIDTH
                                    << GUI::Style::ITEM_SELECTOR_WIDGET_WIDTH * 7);

    if (selector->currentItem())
        stackedWidget->setItem(selector->currentItem());
}
