//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Device/FootprintForm.cpp
//! @brief     Implements class FootprintForm.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Device/FootprintForm.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Beam/FootprintItems.h"
#include "GUI/Model/Beam/SourceItems.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/View/Numeric/ComboUtil.h"
#include "GUI/View/Numeric/DoubleSpinBox.h"
#include "GUI/View/Numeric/NumWidgetUtil.h"

FootprintForm::FootprintForm(QWidget* parent, SourceItem* item)
    : StaticGroupBox("Footprint correction", parent)
    , m_formLayout(new QFormLayout(body()))
    , m_item(item)
{
    m_formLayout->setFieldGrowthPolicy(QFormLayout::FieldsStayAtSizeHint);
    ASSERT(item->footprintSelection().currentItem());
    auto* typeCombo = GUI::Util::createComboBoxFromProperty(
        item->footprintSelection(),
        [this](int) {
            updateFootprintWidgets();
            emit dataChanged();
        },
        true);
    m_formLayout->addRow("Type:", typeCombo);

    updateFootprintWidgets();
}

void FootprintForm::updateFootprintWidgets()
{
    while (m_formLayout->rowCount() > 1)
        m_formLayout->removeRow(1);

    int sb_width = 134;
    auto* footprintItem = m_item->footprintSelection().currentItem();
    if (auto* sqr = dynamic_cast<FootprintSquareItem*>(footprintItem)) {
        auto* sb = GUI::Util::createDoubleSpinBoxRow(m_formLayout, sqr->squareFootprintValue());
        sb->setMinimumWidth(sb_width);
        connect(sb, &DoubleSpinBox::valueChanged, [this, sqr](double v) {
            sqr->setSquareFootprintValue(v);
            emit dataChanged();
        });
    } else if (auto* gs = dynamic_cast<FootprintGaussianItem*>(footprintItem)) {
        auto* sb = GUI::Util::createDoubleSpinBoxRow(m_formLayout, gs->gaussianFootprintValue());
        sb->setMinimumWidth(sb_width);
        connect(sb, &DoubleSpinBox::valueChanged, [this, gs](double v) {
            gs->setGaussianFootprintValue(v);
            emit dataChanged();
        });
    }
}
