//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Frame/Plot2DFrame.cpp
//! @brief     Implements class Plot2DFrame.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Frame/Plot2DFrame.h"
#include "GUI/Model/Data/Data2DItem.h"
#include "GUI/View/Canvas/IntensityDataCanvas.h"
#include "GUI/View/Setup/Scale2DEditor.h"
#include "GUI/View/Tool/ActionFactory.h"
#include <QBoxLayout>
#include <QMenu>

Plot2DFrame::Plot2DFrame()
    : DataAccessWidget(nullptr)
    , m_intensityCanvas(new IntensityDataCanvas)
    , m_scaleEditor(new Scale2DEditor(this))
    , m_togglePropertiesAction(
          ActionFactory::createTogglePropertiesPanelAction(this, m_scaleEditor))
{
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);

    auto* layout = new QHBoxLayout;
    setLayout(layout);
    layout->setContentsMargins(0, 0, 0, 0);
    layout->setSpacing(0);

    layout->addWidget(m_intensityCanvas);

    layout->addWidget(m_scaleEditor);
    m_scaleEditor->setVisible(false);
    m_scaleEditor->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);

    connect(m_intensityCanvas, &IntensityDataCanvas::customContextMenuRequested, this,
            &Plot2DFrame::onContextMenuRequest);
}

void Plot2DFrame::setJobOrDatafileItem(QObject* item)
{
    setBaseItem(item);
    m_intensityCanvas->setJobOrDatafileItem(item);
    m_scaleEditor->setJobOrDatafileItem(item);
}

QList<QAction*> Plot2DFrame::actionList()
{
    return m_intensityCanvas->actionList() + QList<QAction*>{m_togglePropertiesAction};
}

void Plot2DFrame::onContextMenuRequest(const QPoint& point)
{
    QMenu menu;
    for (auto* action : actionList())
        menu.addAction(action);
    menu.exec(point);
}
