//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/ProShape/MaskUtil.cpp
//! @brief     Implements class MaskUtil.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/ProShape/MaskUtil.h"
#include <QColor>

QBrush MaskUtil::getSelectionMarkerBrush()
{
    QBrush result;
    result.setStyle(Qt::SolidPattern);
    result.setColor(QColor(226, 235, 244));
    return result;
}

QPen MaskUtil::getSelectionMarkerPen()
{
    return {QColor(99, 162, 217)};
}

QBrush MaskUtil::getMaskBrush(bool mask_value)
{
    if (!mask_value)
        return Qt::NoBrush;
    return {QColor(0, 0, 80)}; // deep blue
}

QPen MaskUtil::getMaskPen(bool mask_value)
{
    if (mask_value)
        return {QColor(165, 80, 76)}; // dark red
    return {QColor(0, 140, 70)};      // dark green
}

QRectF MaskUtil::getMarkerRectangle(const QPointF& pos)
{
    QRectF result(0, 0, 7, 7);
    result.moveCenter(pos);
    return result;
}
