//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/ProShape/SceneAdaptor.h
//! @brief     Defines class SceneAdaptor.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_PROSHAPE_SCENEADAPTOR_H
#define BORNAGAIN_GUI_VIEW_PROSHAPE_SCENEADAPTOR_H

#include <QObject>
#include <QRectF>

class ColorMap;

//! Performs conversion of MaskItems coordinates between ColorMap and GraphicsScene.

class SceneAdaptor : public QObject {
    Q_OBJECT
public:
    SceneAdaptor();

    qreal toSceneX(qreal v) const;
    qreal toSceneY(qreal v) const;
    qreal fromSceneX(qreal p) const;
    qreal fromSceneY(qreal p) const;

    void setColorMapPlot(ColorMap* plot);

    bool eventFilter(QObject* object, QEvent* event) override;

    //! Returns ColorMapPlot axes rectangle (at current zoom level) in scene coordinates
    const QRectF& viewportRectangle() const { return m_viewport_rectangle; }

signals:
    void update_request();

private:
    QRectF m_viewport_rectangle;
    ColorMap* m_plot;
};

#endif // BORNAGAIN_GUI_VIEW_PROSHAPE_SCENEADAPTOR_H
