//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Scene/MaskViewFactory.cpp
//! @brief     Implements class MaskViewFactory.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Scene/MaskViewFactory.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Mask/MaskItems.h"
#include "GUI/Model/Mask/ProjectionContainerItem.h"
#include "GUI/View/Scene/RegionOfInterestDisplay.h"
#include "GUI/View/Shape/AllMasksDisplay.h"
#include "GUI/View/Shape/EllipseDisplay.h"
#include "GUI/View/Shape/LineDisplays.h"
#include "GUI/View/Shape/MaskContainerDisplay.h"
#include "GUI/View/Shape/PolygonDisplay.h"
#include "GUI/View/Shape/PolygonPointDisplay.h"

IShapeDisplay* MaskViewFactory::createMaskView(MaskObject* item)
{
    if (auto* mask = dynamic_cast<MaskContainerItem*>(item))
        // includes ProjectionContainerItem
        return new MaskContainerDisplay(mask);

    if (auto* mask = dynamic_cast<RectangleItem*>(item))
        return new RectangleDisplay(mask);

    if (auto* mask = dynamic_cast<PolygonItem*>(item))
        return new PolygonDisplay(mask);

    if (auto* mask = dynamic_cast<PolygonPointItem*>(item))
        return new PolygonPointDisplay(mask);

    if (auto* mask = dynamic_cast<VerticalLineItem*>(item))
        return new VerticalLineDisplay(mask);

    if (auto* mask = dynamic_cast<HorizontalLineItem*>(item))
        return new HorizontalLineDisplay(mask);

    if (auto* mask = dynamic_cast<EllipseItem*>(item))
        return new EllipseDisplay(mask);

    if (auto* mask = dynamic_cast<MaskAllItem*>(item))
        return new AllMasksDisplay(mask);

    if (auto* mask = dynamic_cast<RegionOfInterestItem*>(item))
        return new RegionOfInterestDisplay(mask);

    ASSERT_NEVER;
}
