//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Shape/PolygonPointDisplay.h
//! @brief     Defines class PolygonPointDisplay.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SHAPE_POLYGONPOINTDISPLAY_H
#define BORNAGAIN_GUI_VIEW_SHAPE_POLYGONPOINTDISPLAY_H

#include "GUI/View/Shape/IShapeDisplay.h"

class PolygonPointItem;

//! This is a View of polygon point for PolygonMaskItem

class PolygonPointDisplay : public IShapeDisplay {
    Q_OBJECT
public:
    int type() const override { return MaskType::POLYGONPOINT; }

    explicit PolygonPointDisplay(PolygonPointItem* item);

    QRectF boundingRect() const override;

    MaskObject* parameterizedItem() const override;

    void updateParameterizedItem(const QPointF& pos);

signals:
    void closePolygonRequest(bool);
    void propertyChanged();

protected slots:
    void update_view() override;
    void onPropertyChange() override;

protected:
    void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event) override;

private:
    PolygonPointItem* m_item;
    bool m_on_hover;
};

#endif // BORNAGAIN_GUI_VIEW_SHAPE_POLYGONPOINTDISPLAY_H
